:py:mod:`piel.models.frequency.photonic.straight_waveguide`
===========================================================

.. py:module:: piel.models.frequency.photonic.straight_waveguide

.. autoapi-nested-parse::

   Translated from https://github.com/flaport/sax or https://github.com/flaport/photontorch/tree/master



Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.frequency.photonic.straight_waveguide.waveguide
   piel.models.frequency.photonic.straight_waveguide.ideal_active_waveguide
   piel.models.frequency.photonic.straight_waveguide.simple_straight
   piel.models.frequency.photonic.straight_waveguide.lossless_straight



.. py:function:: waveguide(wl=1.55, wl0=1.55, neff=2.34, ng=3.4, length=10.0, loss=0.0)


.. py:function:: ideal_active_waveguide(wl=1.55, wl0=1.55, neff=2.34, ng=3.4, length=10.0, loss=0.0, active_phase_rad=0.0)


.. py:function:: simple_straight(length=10.0, width=0.5)


.. py:function:: lossless_straight()
